# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OvulationTestEntryTestResult(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    NEGATIVE = "negative"
    POSITIVE = "positive"
    LUTEINIZING_HORMONE_SURGE = "luteinizing_hormone_surge"
    ESTROGEN_SURGE = "estrogen_surge"
    INDETERMINATE = "indeterminate"
    _UNKNOWN = "__OVULATIONTESTENTRYTESTRESULT_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "OvulationTestEntryTestResult":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        negative: typing.Callable[[], T_Result],
        positive: typing.Callable[[], T_Result],
        luteinizing_hormone_surge: typing.Callable[[], T_Result],
        estrogen_surge: typing.Callable[[], T_Result],
        indeterminate: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is OvulationTestEntryTestResult.NEGATIVE:
            return negative()
        if self is OvulationTestEntryTestResult.POSITIVE:
            return positive()
        if self is OvulationTestEntryTestResult.LUTEINIZING_HORMONE_SURGE:
            return luteinizing_hormone_surge()
        if self is OvulationTestEntryTestResult.ESTROGEN_SURGE:
            return estrogen_surge()
        if self is OvulationTestEntryTestResult.INDETERMINATE:
            return indeterminate()
        return _unknown_member(self._value_)
